@@ -262,25 +262,31 @@ class Book:
             self.xl.save()
         elif (saved_path != '') and (path is not None) and (os.path.split(path)[0] == ''):
             # Save existing book under new name in cwd if no path has been provided
+            save_as_name = path
             path = os.path.join(os.getcwd(), path)
             hfs_path = posix_to_hfs_path(os.path.realpath(path))
             self.xl.save_workbook_as(filename=hfs_path, overwrite=True)
+            self.xl = self.app.xl.workbooks[save_as_name]
         elif (saved_path == '') and (path is None):
             # Previously unsaved: Save under current name in current working directory
-            path = os.path.join(os.getcwd(), self.xl.name.get() + '.xlsx')
+            save_as_name = self.xl.name.get() + '.xlsx'
+            path = os.path.join(os.getcwd(), save_as_name)
             hfs_path = posix_to_hfs_path(os.path.realpath(path))
             self.xl.save_workbook_as(filename=hfs_path, overwrite=True)
+            self.xl = self.app.xl.workbooks[save_as_name]
         elif path:
             # Save under new name/location
             hfs_path = posix_to_hfs_path(os.path.realpath(path))
             self.xl.save_workbook_as(filename=hfs_path, overwrite=True)
+            self.xl = self.app.xl.workbooks[os.path.basename(path)]
 
     @property
     def fullname(self):
+        display_alerts = self.app.display_alerts
+        self.app.display_alerts = False
+        # This causes a pop-up if there's a pw protected sheet, see #1377
         hfs_path = self.xl.properties().get(kw.full_name)
-        # Excel 2011 returns HFS path, Excel 2016 returns POSIX path
-        if hfs_path == self.xl.properties().get(kw.name) or int(self.app.version.split('.')[0]) >= 15:
-            return hfs_path
+        self.app.display_alerts = display_alerts
         return hfs_to_posix_path(hfs_path)
 
     @property
